@@ -5,11 +5,14 @@
     headers:
 
     > [ ("X-Accel-Buffering", "no"), ("Cache-Control", "no-cache")]
+
+    There is a small example using these functions in the @example@ directory.
 -}
 module Network.Wai.EventSource (
     ServerEvent(..),
     eventSourceAppChan,
-    eventSourceAppIO
+    eventSourceAppIO,
+    eventStreamAppRaw
     ) where
 
 import           Data.Function (fix)
@@ -39,3 +42,18 @@ eventSourceAppIO src _ sendResponse =
             case eventToBuilder se of
                 Nothing -> return ()
                 Just b  -> sendChunk b >> flush >> loop
+
+-- | Make a new WAI EventSource application with a handler that emits events.
+--
+-- @since 3.0.28
+eventStreamAppRaw :: ((ServerEvent -> IO()) -> IO () -> IO ()) -> Application
+eventStreamAppRaw handler _ sendResponse =
+    sendResponse $ responseStream
+        status200
+        [(hContentType, "text/event-stream")]
+        $ \sendChunk flush -> handler (sendEvent sendChunk) flush
+    where
+        sendEvent sendChunk event =
+            case eventToBuilder event of
+                Nothing -> return ()
+                Just b  -> sendChunk b
